"""
Preprocessor used in kaitai struct to remove the escape sequences of
an ELFIN STAR telemetry frame
"""
#
# Patrick Dohmen, DL4PD (dl4pd@darc.de)
# With the kind help of Mikhail Yakshin
#
# Usage in 'kaitai struct':
#
# types:
#   preprocessor:
#     seq:
#       - id: databuf
#         process: elfin_pp
#         size-eos: true
#
from __future__ import absolute_import, division, print_function

import binascii


class ElfinPp(object):  # pylint: disable=too-few-public-methods
    """
    ELFIN preprocessor class
    """

    def __init__(self):
        pass

    def decode(self, in_bindata):  # pylint: disable=no-self-use
        """
        ELFIN preprocessor decoding method
        """
        bindata = bytearray(in_bindata)
        i = 0
        binlen = len(bindata)
        out = bytearray(b'')
        while i < binlen:
            char = bindata[i]
            if char == 0x27 and i + 1 < binlen:
                next_char = bindata[i + 1]
                if next_char in [0x27, 0x5e, 0x9e]:
                    i += 1
            out.append(bindata[i])
            i += 1
        return out


if __name__ == "__main__":

    # some examples
    DEC = ElfinPp()
    print(binascii.hexlify(binascii.unhexlify('0011272722')))
    print(binascii.hexlify(DEC.decode(binascii.unhexlify('0011272722'))))

    print(binascii.hexlify(binascii.unhexlify('0011a2727220')))
    print(binascii.hexlify(DEC.decode(binascii.unhexlify('0011a2727220'))))

    print(binascii.hexlify(binascii.unhexlify('930027005e0027932727275e')))
    print(binascii.hexlify(
        DEC.decode(binascii.unhexlify('930027005e0027932727275e'))))



# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
from kaitaistruct import __version__ as ks_version, KaitaiStruct, KaitaiStream, BytesIO


if parse_version(ks_version) < parse_version('0.7'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.7 or later is required, but you have %s" % (ks_version))

class Strand(KaitaiStruct):
    """
    .. seealso::
       Source - https://amsat-uk.org/satellites/telemetry/strand-1/strand-1-telemetry/
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.hdlc_flag = self._io.ensure_fixed_contents(b"\xC0\x80")
        self.seq_no = self._io.read_u1()
        self.length = self._io.read_u1()
        self.packet_type = self._io.read_u1()
        _on = self.packet_type
        if _on == 1:
            self.body = self._root.ModemBeaconTlm(self._io, self, self._root)
        elif _on == 2:
            self.body = self._root.ObcBeaconTlm(self._io, self, self._root)
        self.crc_16_ccit = self._io.read_bytes(2)

    class ChAdc1PyArrayCurrent(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc1_py_array_current = self._io.read_u1()


    class ChSwitch1Ppt12Status(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.switch_1_ppt_1_2_status = self._io.read_u1()


    class ChAdc9ArrayPairZVoltage(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc9_array_pair_z_voltage = self._io.read_u1()


    class ChBattery1CurrentDirection(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.battery_1_current_direction = self._io.read_u1()


    class ModemBeaconTlm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.channel = self._io.read_u1()
            _on = self.channel
            if _on == 224:
                self.data = self._root.ChTimeSinceLastObcI2cMessage(self._io, self, self._root)
            elif _on == 227:
                self.data = self._root.ChPacketsUpDroppedCount(self._io, self, self._root)
            elif _on == 226:
                self.data = self._root.ChPacketsDownCount(self._io, self, self._root)
            elif _on == 225:
                self.data = self._root.ChPacketsUpCount(self._io, self, self._root)
            elif _on == 228:
                self.data = self._root.ChPacketsDownDroppedCount(self._io, self, self._root)


    class ChMagnetometerSet1(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.magnetometer_set_1 = self._io.read_u1()


    class CsBattery(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.i2c_node_address = self._io.read_u1()
            _on = self.i2c_node_address
            if _on == 14:
                self.node = self._root.ChAdc14PxArrayTemperature(self._io, self, self._root)
            elif _on == 10:
                self.node = self._root.ChAdc10PzArrayCurrent(self._io, self, self._root)
            elif _on == 17:
                self.node = self._root.ChAdc17BatteryBusCurrent(self._io, self, self._root)
            elif _on == 4:
                self.node = self._root.ChAdc4MyArrayCurrent(self._io, self, self._root)
            elif _on == 6:
                self.node = self._root.ChAdc6ArrayPairXVoltage(self._io, self, self._root)
            elif _on == 7:
                self.node = self._root.ChAdc7MxArrayCurrent(self._io, self, self._root)
            elif _on == 1:
                self.node = self._root.ChAdc1PyArrayCurrent(self._io, self, self._root)
            elif _on == 27:
                self.node = self._root.ChAdc2733vBusCurrent(self._io, self, self._root)
            elif _on == 13:
                self.node = self._root.ChAdc13PxArrayCurrent(self._io, self, self._root)
            elif _on == 11:
                self.node = self._root.ChAdc11PzArrayTemperature(self._io, self, self._root)
            elif _on == 3:
                self.node = self._root.ChAdc3ArrayPairYVoltage(self._io, self, self._root)
            elif _on == 5:
                self.node = self._root.ChAdc5MyArrayTemperature(self._io, self, self._root)
            elif _on == 8:
                self.node = self._root.ChAdc8MxArrayTemperature(self._io, self, self._root)
            elif _on == 9:
                self.node = self._root.ChAdc9ArrayPairZVoltage(self._io, self, self._root)
            elif _on == 26:
                self.node = self._root.ChAdc265vBusCurrent(self._io, self, self._root)
            elif _on == 31:
                self.node = self._root.ChAdc31MzArrayCurrent(self._io, self, self._root)
            elif _on == 2:
                self.node = self._root.ChAdc2PyArrayTemperature(self._io, self, self._root)
            elif _on == 30:
                self.node = self._root.ChAdc30MzArrayTemperature(self._io, self, self._root)


    class ChAdc3ArrayPairYVoltage(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc3_array_pair_y_voltage = self._io.read_u1()


    class ChSwitch9SolarPanelDeployFire(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.switch_9_solar_panel_deploy_fire = self._io.read_u1()


    class ChBattery1VoltageV(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.battery_1_voltage_v = self._io.read_u1()


    class ChAdc4MyArrayCurrent(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc4_my_array_current = self._io.read_u1()


    class ChAdc2PyArrayTemperature(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc2_py_array_temperature = self._io.read_u1()


    class ChUnixTimeLittleEndian(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.unix_time_little_endian = self._io.read_u1()


    class ChTimeSinceLastObcI2cMessage(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.time_since_last_obc_i2c_message = self._io.read_u1()


    class ChSwitch0PptPowerSupplyStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.switch_0_ppt_power_supply_status = self._io.read_u1()


    class ChBattery0CurrentDirection(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.battery_0_current_direction = self._io.read_u1()


    class ObcData(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.i2c_node_address = self._io.read_u1()
            _on = self.i2c_node_address
            if _on == 12:
                self.node = self._root.ChUnixTimeLittleEndian(self._io, self, self._root)


    class ChMagnetometerSet2(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.magnetometer_set_2 = self._io.read_u1()


    class ChAdc2733vBusCurrent(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc27_33v_bus_current = self._io.read_u1()


    class ChSwitch6Sgr05Status(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.switch_6_sgr05_status = self._io.read_u1()


    class CsEps(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.i2c_node_address = self._io.read_u1()
            _on = self.i2c_node_address
            if _on == 0:
                self.node = self._root.ChBattery0CurrentDirection(self._io, self, self._root)
            elif _on == 4:
                self.node = self._root.ChBattery0TemperatureDegC(self._io, self, self._root)
            elif _on == 6:
                self.node = self._root.ChBattery1CurrentMa(self._io, self, self._root)
            elif _on == 1:
                self.node = self._root.ChBattery0CurrentMa(self._io, self, self._root)
            elif _on == 3:
                self.node = self._root.ChBattery0VoltageV(self._io, self, self._root)
            elif _on == 5:
                self.node = self._root.ChBattery1CurrentDirection(self._io, self, self._root)
            elif _on == 8:
                self.node = self._root.ChBattery1VoltageV(self._io, self, self._root)
            elif _on == 9:
                self.node = self._root.ChBattery1TemperatureDegC(self._io, self, self._root)


    class ChAdc7MxArrayCurrent(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc7_mx_array_current = self._io.read_u1()


    class ChAdc31MzArrayCurrent(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc31_mz_array_current = self._io.read_u1()


    class ChSwitch8SolarPanelDeployArm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.switch_8_solar_panel_deploy_arm = self._io.read_u1()


    class ChAdc5MyArrayTemperature(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc5_my_array_temperature = self._io.read_u1()


    class ChPacketsDownDroppedCount(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.packets_down_dropped_count = self._io.read_u1()


    class ObcBeaconTlm(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.i2c_node_address = self._io.read_u1()
            _on = self.i2c_node_address
            if _on == 45:
                self.node = self._root.CsBattery(self._io, self, self._root)
            elif _on == 137:
                self.node = self._root.Magnetometers(self._io, self, self._root)
            elif _on == 44:
                self.node = self._root.CsEps(self._io, self, self._root)
            elif _on == 102:
                self.node = self._root.SwitchBoard(self._io, self, self._root)
            elif _on == 128:
                self.node = self._root.ObcData(self._io, self, self._root)


    class ChPacketsUpCount(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.packets_up_count = self._io.read_u1()


    class ChSwitch3WarpValveStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.switch_3_warp_valve_status = self._io.read_u1()


    class ChBattery0VoltageV(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.battery_0_voltage_v = self._io.read_u1()


    class ChAdc13PxArrayCurrent(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc13_px_array_current = self._io.read_u1()


    class ChAdc30MzArrayTemperature(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc30_mz_array_temperature = self._io.read_u1()


    class ChAdc8MxArrayTemperature(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc8_mx_array_temperature = self._io.read_u1()


    class ChAdc14PxArrayTemperature(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc14_px_array_temperature = self._io.read_u1()


    class ChBattery0CurrentMa(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.battery_0_current_ma = self._io.read_u1()


    class ChAdc6ArrayPairXVoltage(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc6_array_pair_x_voltage = self._io.read_u1()


    class ChSwitch2Phone5vWebcam(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.switch_2_phone_5v_webcam = self._io.read_u1()


    class ChPacketsDownCount(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.packets_down_count = self._io.read_u1()


    class ChAdc10PzArrayCurrent(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc10_pz_array_current = self._io.read_u1()


    class ChAdc17BatteryBusCurrent(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc17_battery_bus_current = self._io.read_u1()


    class ChAdc11PzArrayTemperature(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc11_pz_array_temperature = self._io.read_u1()


    class ChSwitch4WarpHeaterStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.switch_4_warp_heater_status = self._io.read_u1()


    class ChPacketsUpDroppedCount(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.packets_up_dropped_count = self._io.read_u1()


    class ChSwitch7ReactionWheels(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.switch_7_reaction_wheels = self._io.read_u1()


    class ChBattery1TemperatureDegC(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.battery_1_temperature_deg_c = self._io.read_u1()


    class ChSwitch5DigiWi9cStatus(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.switch_5_digi_wi9c_status = self._io.read_u1()


    class SwitchBoard(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.i2c_node_address = self._io.read_u1()
            _on = self.i2c_node_address
            if _on == 159:
                self.node = self._root.ChSwitch6Sgr05Status(self._io, self, self._root)
            elif _on == 169:
                self.node = self._root.ChSwitch8SolarPanelDeployArm(self._io, self, self._root)
            elif _on == 144:
                self.node = self._root.ChSwitch3WarpValveStatus(self._io, self, self._root)
            elif _on == 149:
                self.node = self._root.ChSwitch4WarpHeaterStatus(self._io, self, self._root)
            elif _on == 172:
                self.node = self._root.ChSwitch9SolarPanelDeployFire(self._io, self, self._root)
            elif _on == 164:
                self.node = self._root.ChSwitch7ReactionWheels(self._io, self, self._root)
            elif _on == 129:
                self.node = self._root.ChSwitch0PptPowerSupplyStatus(self._io, self, self._root)
            elif _on == 134:
                self.node = self._root.ChSwitch1Ppt12Status(self._io, self, self._root)
            elif _on == 139:
                self.node = self._root.ChSwitch2Phone5vWebcam(self._io, self, self._root)
            elif _on == 154:
                self.node = self._root.ChSwitch5DigiWi9cStatus(self._io, self, self._root)


    class ChBattery0TemperatureDegC(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.battery_0_temperature_deg_c = self._io.read_u1()


    class ChAdc265vBusCurrent(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.adc26_5v_bus_current = self._io.read_u1()


    class Magnetometers(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.i2c_node_address = self._io.read_u1()
            _on = self.i2c_node_address
            if _on == 3:
                self.node = self._root.ChMagnetometerSet1(self._io, self, self._root)
            elif _on == 5:
                self.node = self._root.ChMagnetometerSet2(self._io, self, self._root)


    class ChBattery1CurrentMa(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.battery_1_current_ma = self._io.read_u1()






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
from kaitaistruct import __version__ as ks_version, KaitaiStruct, KaitaiStream, BytesIO


if parse_version(ks_version) < parse_version('0.7'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.7 or later is required, but you have %s" % (ks_version))

class Cubesatsim(KaitaiStruct):
    """:field dest_callsign: ax25_frame.ax25_header.dest_callsign_raw.callsign_ror.callsign
    :field src_callsign: ax25_frame.ax25_header.src_callsign_raw.callsign_ror.callsign
    :field src_ssid: ax25_frame.ax25_header.src_ssid_raw.ssid
    :field dest_ssid: ax25_frame.ax25_header.dest_ssid_raw.ssid
    :field ctl: ax25_frame.ax25_header.ctl
    :field pid: ax25_frame.payload.pid
    :field data_type: ax25_frame.payload.ax25_info.data_type
    :field channel_1a_val: ax25_frame.payload.ax25_info.payload.channel_1a_val
    :field channel_1b_val: ax25_frame.payload.ax25_info.payload.channel_1b_val
    :field channel_1c_val: ax25_frame.payload.ax25_info.payload.channel_1c_val
    :field channel_1d_val: ax25_frame.payload.ax25_info.payload.channel_1d_val
    :field channel_2a_val: ax25_frame.payload.ax25_info.payload.channel_2a_val
    :field channel_2b_val: ax25_frame.payload.ax25_info.payload.channel_2b_val
    :field channel_2c_val: ax25_frame.payload.ax25_info.payload.channel_2c_val
    :field channel_2d_val: ax25_frame.payload.ax25_info.payload.channel_2d_val
    :field channel_3a_val: ax25_frame.payload.ax25_info.payload.channel_3a_val
    :field channel_3b_val: ax25_frame.payload.ax25_info.payload.channel_3b_val
    :field channel_3c_val: ax25_frame.payload.ax25_info.payload.channel_3c_val
    :field channel_3d_val: ax25_frame.payload.ax25_info.payload.channel_3d_val
    :field channel_4a_val: ax25_frame.payload.ax25_info.payload.channel_4a_val
    :field channel_4b_val: ax25_frame.payload.ax25_info.payload.channel_4b_val
    :field channel_4c_val: ax25_frame.payload.ax25_info.payload.channel_4c_val
    :field channel_4d_val: ax25_frame.payload.ax25_info.payload.channel_4d_val
    :field channel_5a_val: ax25_frame.payload.ax25_info.payload.channel_5a_val
    :field channel_5b_val: ax25_frame.payload.ax25_info.payload.channel_5b_val
    :field channel_5c_val: ax25_frame.payload.ax25_info.payload.channel_5c_val
    :field channel_5d_val: ax25_frame.payload.ax25_info.payload.channel_5d_val
    :field channel_6a_val: ax25_frame.payload.ax25_info.payload.channel_6a_val
    :field channel_6b_val: ax25_frame.payload.ax25_info.payload.channel_6b_val
    :field channel_6c_val: ax25_frame.payload.ax25_info.payload.channel_6c_val
    :field channel_6d_val: ax25_frame.payload.ax25_info.payload.channel_6d_val
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25_frame = self._root.Ax25Frame(self._io, self, self._root)

    class Ax25Frame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ax25_header = self._root.Ax25Header(self._io, self, self._root)
            _on = (self.ax25_header.ctl & 19)
            if _on == 0:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 3:
                self.payload = self._root.UiFrame(self._io, self, self._root)
            elif _on == 19:
                self.payload = self._root.UiFrame(self._io, self, self._root)
            elif _on == 16:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 18:
                self.payload = self._root.IFrame(self._io, self, self._root)
            elif _on == 2:
                self.payload = self._root.IFrame(self._io, self, self._root)


    class Ax25Header(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.dest_callsign_raw = self._root.CallsignRaw(self._io, self, self._root)
            self.dest_ssid_raw = self._root.SsidMask(self._io, self, self._root)
            self.src_callsign_raw = self._root.CallsignRaw(self._io, self, self._root)
            self.src_ssid_raw = self._root.SsidMask(self._io, self, self._root)
            self.ctl = self._io.read_u1()


    class UiFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self._raw_ax25_info = self._io.read_bytes_full()
            io = KaitaiStream(BytesIO(self._raw_ax25_info))
            self.ax25_info = self._root.Data(io, self, self._root)


    class Callsign(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.callsign = (self._io.read_bytes(6)).decode(u"ASCII")


    class Data(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.data_type = self._io.read_u2be()
            _on = self.data_type
            if _on == 26729:
                self.payload = self._root.Ao7(self._io, self, self._root)
            else:
                self.payload = self._root.Ao7(self._io, self, self._root)


    class IFrame(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.pid = self._io.read_u1()
            self.ax25_info = self._io.read_bytes_full()


    class SsidMask(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ssid_mask = self._io.read_u1()

        @property
        def ssid(self):
            if hasattr(self, '_m_ssid'):
                return self._m_ssid if hasattr(self, '_m_ssid') else None

            self._m_ssid = ((self.ssid_mask & 15) >> 1)
            return self._m_ssid if hasattr(self, '_m_ssid') else None


    class Ao7(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.ao_7_magic = self._io.ensure_fixed_contents(b"\x20\x68\x69\x20")
            self.channel_1a_id = self._io.ensure_fixed_contents(b"\x31")
            self.channel_1a_val_raw = [None] * (2)
            for i in range(2):
                self.channel_1a_val_raw[i] = self._io.read_u1()

            self.delim_1a = self._io.read_bytes(1)
            self.channel_1b_id = self._io.ensure_fixed_contents(b"\x31")
            self.channel_1b_val_raw = [None] * (2)
            for i in range(2):
                self.channel_1b_val_raw[i] = self._io.read_u1()

            self.delim_1b = self._io.read_bytes(1)
            self.channel_1c_id = self._io.ensure_fixed_contents(b"\x31")
            self.channel_1c_val_raw = [None] * (2)
            for i in range(2):
                self.channel_1c_val_raw[i] = self._io.read_u1()

            self.delim_1c = self._io.read_bytes(1)
            self.channel_1d_id = self._io.ensure_fixed_contents(b"\x31")
            self.channel_1d_val_raw = [None] * (2)
            for i in range(2):
                self.channel_1d_val_raw[i] = self._io.read_u1()

            self.delim_1d = self._io.read_bytes(1)
            self.channel_2a_id = self._io.ensure_fixed_contents(b"\x32")
            self.channel_2a_val_raw = [None] * (2)
            for i in range(2):
                self.channel_2a_val_raw[i] = self._io.read_u1()

            self.delim_2a = self._io.read_bytes(1)
            self.channel_2b_id = self._io.ensure_fixed_contents(b"\x32")
            self.channel_2b_val_raw = [None] * (2)
            for i in range(2):
                self.channel_2b_val_raw[i] = self._io.read_u1()

            self.delim_2b = self._io.read_bytes(1)
            self.channel_2c_id = self._io.ensure_fixed_contents(b"\x32")
            self.channel_2c_val_raw = [None] * (2)
            for i in range(2):
                self.channel_2c_val_raw[i] = self._io.read_u1()

            self.delim_2c = self._io.read_bytes(1)
            self.channel_2d_id = self._io.ensure_fixed_contents(b"\x32")
            self.channel_2d_val_raw = [None] * (2)
            for i in range(2):
                self.channel_2d_val_raw[i] = self._io.read_u1()

            self.delim_2d = self._io.read_bytes(1)
            self.channel_3a_id = self._io.ensure_fixed_contents(b"\x33")
            self.channel_3a_val_raw = [None] * (2)
            for i in range(2):
                self.channel_3a_val_raw[i] = self._io.read_u1()

            self.delim_3a = self._io.read_bytes(1)
            self.channel_3b_id = self._io.ensure_fixed_contents(b"\x33")
            self.channel_3b_val_raw = [None] * (2)
            for i in range(2):
                self.channel_3b_val_raw[i] = self._io.read_u1()

            self.delim_3b = self._io.read_bytes(1)
            self.channel_3c_id = self._io.ensure_fixed_contents(b"\x33")
            self.channel_3c_val_raw = [None] * (2)
            for i in range(2):
                self.channel_3c_val_raw[i] = self._io.read_u1()

            self.delim_3c = self._io.read_bytes(1)
            self.channel_3d_id = self._io.ensure_fixed_contents(b"\x33")
            self.channel_3d_val_raw = [None] * (2)
            for i in range(2):
                self.channel_3d_val_raw[i] = self._io.read_u1()

            self.delim_3d = self._io.read_bytes(1)
            self.channel_4a_id = self._io.ensure_fixed_contents(b"\x34")
            self.channel_4a_val_raw = [None] * (2)
            for i in range(2):
                self.channel_4a_val_raw[i] = self._io.read_u1()

            self.delim_4a = self._io.read_bytes(1)
            self.channel_4b_id = self._io.ensure_fixed_contents(b"\x34")
            self.channel_4b_val_raw = [None] * (2)
            for i in range(2):
                self.channel_4b_val_raw[i] = self._io.read_u1()

            self.delim_4b = self._io.read_bytes(1)
            self.channel_4c_id = self._io.ensure_fixed_contents(b"\x34")
            self.channel_4c_val_raw = [None] * (2)
            for i in range(2):
                self.channel_4c_val_raw[i] = self._io.read_u1()

            self.delim_4c = self._io.read_bytes(1)
            self.channel_4d_id = self._io.ensure_fixed_contents(b"\x34")
            self.channel_4d_val_raw = [None] * (2)
            for i in range(2):
                self.channel_4d_val_raw[i] = self._io.read_u1()

            self.delim_4d = self._io.read_bytes(1)
            self.channel_5a_id = self._io.ensure_fixed_contents(b"\x35")
            self.channel_5a_val_raw = [None] * (2)
            for i in range(2):
                self.channel_5a_val_raw[i] = self._io.read_u1()

            self.delim_5a = self._io.read_bytes(1)
            self.channel_5b_id = self._io.ensure_fixed_contents(b"\x35")
            self.channel_5b_val_raw = [None] * (2)
            for i in range(2):
                self.channel_5b_val_raw[i] = self._io.read_u1()

            self.delim_5b = self._io.read_bytes(1)
            self.channel_5c_id = self._io.ensure_fixed_contents(b"\x35")
            self.channel_5c_val_raw = [None] * (2)
            for i in range(2):
                self.channel_5c_val_raw[i] = self._io.read_u1()

            self.delim_5c = self._io.read_bytes(1)
            self.channel_5d_id = self._io.ensure_fixed_contents(b"\x35")
            self.channel_5d_val_raw = [None] * (2)
            for i in range(2):
                self.channel_5d_val_raw[i] = self._io.read_u1()

            self.delim_5d = self._io.read_bytes(1)
            self.channel_6a_id = self._io.ensure_fixed_contents(b"\x36")
            self.channel_6a_val_raw = [None] * (2)
            for i in range(2):
                self.channel_6a_val_raw[i] = self._io.read_u1()

            self.delim_6a = self._io.read_bytes(1)
            self.channel_6b_id = self._io.ensure_fixed_contents(b"\x36")
            self.channel_6b_val_raw = [None] * (2)
            for i in range(2):
                self.channel_6b_val_raw[i] = self._io.read_u1()

            self.delim_6b = self._io.read_bytes(1)
            self.channel_6c_id = self._io.ensure_fixed_contents(b"\x36")
            self.channel_6c_val_raw = [None] * (2)
            for i in range(2):
                self.channel_6c_val_raw[i] = self._io.read_u1()

            self.delim_6c = self._io.read_bytes(1)
            self.channel_6d_id = self._io.ensure_fixed_contents(b"\x36")
            self.channel_6d_val_raw = [None] * (2)
            for i in range(2):
                self.channel_6d_val_raw[i] = self._io.read_u1()

            self.delim_6d = self._io.read_bytes(1)

        @property
        def channel_1d_val(self):
            """1970 - (20 * value) [mA]."""
            if hasattr(self, '_m_channel_1d_val'):
                return self._m_channel_1d_val if hasattr(self, '_m_channel_1d_val') else None

            self._m_channel_1d_val = (((self.channel_1d_val_raw[0] - 48) * 10) + (self.channel_1d_val_raw[1] - 48))
            return self._m_channel_1d_val if hasattr(self, '_m_channel_1d_val') else None

        @property
        def channel_1a_val(self):
            """value * 29.5 [mA]."""
            if hasattr(self, '_m_channel_1a_val'):
                return self._m_channel_1a_val if hasattr(self, '_m_channel_1a_val') else None

            self._m_channel_1a_val = ((((self.channel_1a_val_raw[0] - 48) * 10) + (self.channel_1a_val_raw[1] - 48)) * 29.5)
            return self._m_channel_1a_val if hasattr(self, '_m_channel_1a_val') else None

        @property
        def channel_6a_val(self):
            """value^2 / 1.56 [mA]."""
            if hasattr(self, '_m_channel_6a_val'):
                return self._m_channel_6a_val if hasattr(self, '_m_channel_6a_val') else None

            self._m_channel_6a_val = (((((self.channel_6a_val_raw[0] - 48) * 10) + (self.channel_6a_val_raw[1] - 48)) * (((self.channel_6a_val_raw[0] - 48) * 10) + (self.channel_6a_val_raw[1] - 48))) / 1.56)
            return self._m_channel_6a_val if hasattr(self, '_m_channel_6a_val') else None

        @property
        def channel_1c_val(self):
            """1970 - (20 * value) [mA]."""
            if hasattr(self, '_m_channel_1c_val'):
                return self._m_channel_1c_val if hasattr(self, '_m_channel_1c_val') else None

            self._m_channel_1c_val = (1970 - (20 * (((self.channel_1c_val_raw[0] - 48) * 10) + (self.channel_1c_val_raw[1] - 48))))
            return self._m_channel_1c_val if hasattr(self, '_m_channel_1c_val') else None

        @property
        def channel_4a_val(self):
            """95.8 - 1.48 * value [C]."""
            if hasattr(self, '_m_channel_4a_val'):
                return self._m_channel_4a_val if hasattr(self, '_m_channel_4a_val') else None

            self._m_channel_4a_val = (95.8 - (1.48 * (((self.channel_4a_val_raw[0] - 48) * 10) + (self.channel_4a_val_raw[1] - 48))))
            return self._m_channel_4a_val if hasattr(self, '_m_channel_4a_val') else None

        @property
        def channel_5a_val(self):
            """95.8 - 1.48 * value [C]."""
            if hasattr(self, '_m_channel_5a_val'):
                return self._m_channel_5a_val if hasattr(self, '_m_channel_5a_val') else None

            self._m_channel_5a_val = (95.8 - (1.48 * (((self.channel_5a_val_raw[0] - 48) * 10) + (self.channel_5a_val_raw[1] - 48))))
            return self._m_channel_5a_val if hasattr(self, '_m_channel_5a_val') else None

        @property
        def channel_2b_val(self):
            """8 * (1 - 0.01 * value)^2 [W]."""
            if hasattr(self, '_m_channel_2b_val'):
                return self._m_channel_2b_val if hasattr(self, '_m_channel_2b_val') else None

            self._m_channel_2b_val = (8 * ((1 - (0.01 * (((self.channel_2b_val_raw[0] - 48) * 10) + (self.channel_2b_val_raw[1] - 48)))) * (1 - (0.01 * (((self.channel_2b_val_raw[0] - 48) * 10) + (self.channel_2b_val_raw[1] - 48))))))
            return self._m_channel_2b_val if hasattr(self, '_m_channel_2b_val') else None

        @property
        def channel_6b_val(self):
            """0.1 * value^2 + 35 [mA]."""
            if hasattr(self, '_m_channel_6b_val'):
                return self._m_channel_6b_val if hasattr(self, '_m_channel_6b_val') else None

            self._m_channel_6b_val = ((0.1 * ((((self.channel_6b_val_raw[0] - 48) * 10) + (self.channel_6b_val_raw[1] - 48)) * (((self.channel_6b_val_raw[0] - 48) * 10) + (self.channel_6b_val_raw[1] - 48)))) + 35)
            return self._m_channel_6b_val if hasattr(self, '_m_channel_6b_val') else None

        @property
        def channel_6c_val(self):
            """0.041 * value^2 [mA]."""
            if hasattr(self, '_m_channel_6c_val'):
                return self._m_channel_6c_val if hasattr(self, '_m_channel_6c_val') else None

            self._m_channel_6c_val = (0.041 * ((((self.channel_6c_val_raw[0] - 48) * 10) + (self.channel_6c_val_raw[1] - 48)) * (((self.channel_6c_val_raw[0] - 48) * 10) + (self.channel_6c_val_raw[1] - 48))))
            return self._m_channel_6c_val if hasattr(self, '_m_channel_6c_val') else None

        @property
        def channel_3a_val(self):
            """0.1 * value + 6.4 [V]."""
            if hasattr(self, '_m_channel_3a_val'):
                return self._m_channel_3a_val if hasattr(self, '_m_channel_3a_val') else None

            self._m_channel_3a_val = ((0.1 * (((self.channel_3a_val_raw[0] - 48) * 10) + (self.channel_3a_val_raw[1] - 48))) + 6.4)
            return self._m_channel_3a_val if hasattr(self, '_m_channel_3a_val') else None

        @property
        def channel_2d_val(self):
            """40 * (value - 50) [mA]."""
            if hasattr(self, '_m_channel_2d_val'):
                return self._m_channel_2d_val if hasattr(self, '_m_channel_2d_val') else None

            self._m_channel_2d_val = (40 * ((((self.channel_2d_val_raw[0] - 48) * 10) + (self.channel_2d_val_raw[1] - 48)) - 50))
            return self._m_channel_2d_val if hasattr(self, '_m_channel_2d_val') else None

        @property
        def channel_5d_val(self):
            """11 + 0.82 * value [mA]."""
            if hasattr(self, '_m_channel_5d_val'):
                return self._m_channel_5d_val if hasattr(self, '_m_channel_5d_val') else None

            self._m_channel_5d_val = (11 + (0.82 * (((self.channel_5d_val_raw[0] - 48) * 10) + (self.channel_5d_val_raw[1] - 48))))
            return self._m_channel_5d_val if hasattr(self, '_m_channel_5d_val') else None

        @property
        def channel_2c_val(self):
            """15.16 * value [h]."""
            if hasattr(self, '_m_channel_2c_val'):
                return self._m_channel_2c_val if hasattr(self, '_m_channel_2c_val') else None

            self._m_channel_2c_val = (15.16 * (((self.channel_2c_val_raw[0] - 48) * 10) + (self.channel_2c_val_raw[1] - 48)))
            return self._m_channel_2c_val if hasattr(self, '_m_channel_2c_val') else None

        @property
        def channel_6d_val(self):
            """0.01 * value."""
            if hasattr(self, '_m_channel_6d_val'):
                return self._m_channel_6d_val if hasattr(self, '_m_channel_6d_val') else None

            self._m_channel_6d_val = (0.01 * (((self.channel_6d_val_raw[0] - 48) * 10) + (self.channel_6d_val_raw[1] - 48)))
            return self._m_channel_6d_val if hasattr(self, '_m_channel_6d_val') else None

        @property
        def channel_1b_val(self):
            """1970 - (20 * value) [mA]."""
            if hasattr(self, '_m_channel_1b_val'):
                return self._m_channel_1b_val if hasattr(self, '_m_channel_1b_val') else None

            self._m_channel_1b_val = (1970 - (20 * (((self.channel_1b_val_raw[0] - 48) * 10) + (self.channel_1b_val_raw[1] - 48))))
            return self._m_channel_1b_val if hasattr(self, '_m_channel_1b_val') else None

        @property
        def channel_3b_val(self):
            """0.1 * value [V]."""
            if hasattr(self, '_m_channel_3b_val'):
                return self._m_channel_3b_val if hasattr(self, '_m_channel_3b_val') else None

            self._m_channel_3b_val = (0.1 * (((self.channel_3b_val_raw[0] - 48) * 10) + (self.channel_3b_val_raw[1] - 48)))
            return self._m_channel_3b_val if hasattr(self, '_m_channel_3b_val') else None

        @property
        def channel_4c_val(self):
            """95.8 - 1.48 * value [C]."""
            if hasattr(self, '_m_channel_4c_val'):
                return self._m_channel_4c_val if hasattr(self, '_m_channel_4c_val') else None

            self._m_channel_4c_val = (95.8 - (1.48 * (((self.channel_4c_val_raw[0] - 48) * 10) + (self.channel_4c_val_raw[1] - 48))))
            return self._m_channel_4c_val if hasattr(self, '_m_channel_4c_val') else None

        @property
        def channel_5c_val(self):
            """95.8 - 1.48 * value [C]."""
            if hasattr(self, '_m_channel_5c_val'):
                return self._m_channel_5c_val if hasattr(self, '_m_channel_5c_val') else None

            self._m_channel_5c_val = (95.8 - (1.48 * (((self.channel_5c_val_raw[0] - 48) * 10) + (self.channel_5c_val_raw[1] - 48))))
            return self._m_channel_5c_val if hasattr(self, '_m_channel_5c_val') else None

        @property
        def channel_4b_val(self):
            """95.8 - 1.48 * value [C]."""
            if hasattr(self, '_m_channel_4b_val'):
                return self._m_channel_4b_val if hasattr(self, '_m_channel_4b_val') else None

            self._m_channel_4b_val = (95.8 - (1.48 * (((self.channel_4b_val_raw[0] - 48) * 10) + (self.channel_4b_val_raw[1] - 48))))
            return self._m_channel_4b_val if hasattr(self, '_m_channel_4b_val') else None

        @property
        def channel_3d_val(self):
            """95.8 - 1.48 * value [C]."""
            if hasattr(self, '_m_channel_3d_val'):
                return self._m_channel_3d_val if hasattr(self, '_m_channel_3d_val') else None

            self._m_channel_3d_val = (95.8 - (1.48 * (((self.channel_3d_val_raw[0] - 48) * 10) + (self.channel_3d_val_raw[1] - 48))))
            return self._m_channel_3d_val if hasattr(self, '_m_channel_3d_val') else None

        @property
        def channel_2a_val(self):
            """1970 - (20 * value) [mA]."""
            if hasattr(self, '_m_channel_2a_val'):
                return self._m_channel_2a_val if hasattr(self, '_m_channel_2a_val') else None

            self._m_channel_2a_val = (1970 - (20 * (((self.channel_2a_val_raw[0] - 48) * 10) + (self.channel_2a_val_raw[1] - 48))))
            return self._m_channel_2a_val if hasattr(self, '_m_channel_2a_val') else None

        @property
        def channel_4d_val(self):
            """95.8 - 1.48 * value [C]."""
            if hasattr(self, '_m_channel_4d_val'):
                return self._m_channel_4d_val if hasattr(self, '_m_channel_4d_val') else None

            self._m_channel_4d_val = (95.8 - (1.48 * (((self.channel_4d_val_raw[0] - 48) * 10) + (self.channel_4d_val_raw[1] - 48))))
            return self._m_channel_4d_val if hasattr(self, '_m_channel_4d_val') else None

        @property
        def channel_3c_val(self):
            """0.15 * value [V]."""
            if hasattr(self, '_m_channel_3c_val'):
                return self._m_channel_3c_val if hasattr(self, '_m_channel_3c_val') else None

            self._m_channel_3c_val = (0.15 * (((self.channel_3c_val_raw[0] - 48) * 10) + (self.channel_3c_val_raw[1] - 48)))
            return self._m_channel_3c_val if hasattr(self, '_m_channel_3c_val') else None

        @property
        def channel_5b_val(self):
            """11.67 * value [mA]."""
            if hasattr(self, '_m_channel_5b_val'):
                return self._m_channel_5b_val if hasattr(self, '_m_channel_5b_val') else None

            self._m_channel_5b_val = (11.67 * (((self.channel_5b_val_raw[0] - 48) * 10) + (self.channel_5b_val_raw[1] - 48)))
            return self._m_channel_5b_val if hasattr(self, '_m_channel_5b_val') else None


    class CallsignRaw(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self._raw__raw_callsign_ror = self._io.read_bytes(6)
            self._raw_callsign_ror = KaitaiStream.process_rotate_left(self._raw__raw_callsign_ror, 8 - (1), 1)
            io = KaitaiStream(BytesIO(self._raw_callsign_ror))
            self.callsign_ror = self._root.Callsign(io, self, self._root)






# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
from kaitaistruct import __version__ as ks_version, KaitaiStruct, KaitaiStream, BytesIO


if parse_version(ks_version) < parse_version('0.7'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.7 or later is required, but you have %s" % (ks_version))

class Siriussat(KaitaiStruct):
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.ax25header = self._io.read_bytes(16)
        self.unknown0 = self._io.read_u1()
        self.unknown1 = self._io.read_bytes(7)
        _on = self.unknown0
        if _on == 22:
            self.body = self._root.Beacon(self._io, self, self._root)
        elif _on == 23:
            self.body = self._root.Extendedbeacon(self._io, self, self._root)

    class Beacon(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.usb1 = self._io.read_u2le()
            self.usb2 = self._io.read_u2le()
            self.usb3 = self._io.read_u2le()
            self.isb1 = self._io.read_u2le()
            self.isb2 = self._io.read_u2le()
            self.isb3 = self._io.read_u2le()
            self.iab = self._io.read_s2le()
            self.ich1 = self._io.read_u2le()
            self.ich2 = self._io.read_u2le()
            self.ich3 = self._io.read_u2le()
            self.ich4 = self._io.read_u2le()
            self.t1_pw = self._io.read_s2le()
            self.t2_pw = self._io.read_s2le()
            self.t3_pw = self._io.read_s2le()
            self.t4_pw = self._io.read_s2le()
            self.uab_crit = self._io.read_bits_int(1) != 0
            self.uab_min = self._io.read_bits_int(1) != 0
            self.heater2_manual = self._io.read_bits_int(1) != 0
            self.heater1_manual = self._io.read_bits_int(1) != 0
            self.heater2_on = self._io.read_bits_int(1) != 0
            self.heater1_on = self._io.read_bits_int(1) != 0
            self.tab_max = self._io.read_bits_int(1) != 0
            self.tab_min = self._io.read_bits_int(1) != 0
            self.channelon4 = self._io.read_bits_int(1) != 0
            self.channelon3 = self._io.read_bits_int(1) != 0
            self.channelon2 = self._io.read_bits_int(1) != 0
            self.channelon1 = self._io.read_bits_int(1) != 0
            self.ich_limit4 = self._io.read_bits_int(1) != 0
            self.ich_limit3 = self._io.read_bits_int(1) != 0
            self.ich_limit2 = self._io.read_bits_int(1) != 0
            self.ich_limit1 = self._io.read_bits_int(1) != 0
            self.reserved0 = self._io.read_bits_int(7)
            self.charger = self._io.read_bits_int(1) != 0
            self._io.align_to_byte()
            self.reserved1 = self._io.read_u1()
            self.uab = self._io.read_s2le()
            self.reg_tel_id = self._io.read_u4le()
            self.pss_time = self._io.read_s4le()
            self.pss_nres = self._io.read_u1()
            self.psdd_fl = self._io.read_u1()
            self.t_amp = self._io.read_s1()
            self.t_uhf = self._io.read_s1()
            self.rssirx = self._io.read_s1()
            self.rssiidle = self._io.read_s1()
            self.pf = self._io.read_s1()
            self.pb = self._io.read_s1()
            self.uhf_nres = self._io.read_u1()
            self.uhf_fl = self._io.read_u1()
            self.uhf_time = self._io.read_s4le()
            self.uptime = self._io.read_u4le()
            self.current = self._io.read_u2le()
            self.uuhf = self._io.read_s2le()


    class Extendedbeacon(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.t_mb = self._io.read_s2le()
            self.mx = self._io.read_f4le()
            self.my = self._io.read_f4le()
            self.mz = self._io.read_f4le()
            self.vx = self._io.read_f4le()
            self.vy = self._io.read_f4le()
            self.vz = self._io.read_f4le()
            self.nres = self._io.read_u1()
            self.rcon = self._io.read_u1()
            self.fl = self._io.read_u1()
            self.time = self._io.read_s4le()
            self.payload_flags = self._io.read_u1()
            self.timesend = self._io.read_s4le()
            self.t_plate = self._io.read_s2le()
            self.t_cpu = self._io.read_s2le()
            self.cursens1 = self._io.read_u2le()
            self.cursens2 = self._io.read_u2le()
            self.nrst = self._io.read_u1()
            self.timerst = self._io.read_s4le()
            self.ch1rate = self._io.read_u2le()
            self.ch2rate = self._io.read_u2le()
            self.ch3rate = self._io.read_u2le()
            self.ch4rate = self._io.read_u2le()
            self.ch5rate = self._io.read_u2le()
            self.ch6rate = self._io.read_u2le()
            self.ptrend1 = self._io.read_u2le()
            self.ptrcrt1 = self._io.read_u2le()
            self.ptrend2 = self._io.read_u2le()
            self.ptrcrt2 = self._io.read_u2le()
            self.ptrend3 = self._io.read_u2le()
            self.ptrcrt3 = self._io.read_u2le()
            self.lastevent_ch1_1 = self._io.read_u1()
            self.lastevent_ch1_2 = self._io.read_u1()
            self.lastevent_ch1_3 = self._io.read_u1()
            self.lastevent_ch2_1 = self._io.read_u1()
            self.lastevent_ch2_2 = self._io.read_u1()
            self.lastevent_ch2_3 = self._io.read_u1()



